/**
 * Sets up GPIO interrupts and configures the pins.
 * Also provides a common interface to EINT3_IRQHandler by providing
 * a subscribe function
 */

#ifndef GPIOINT_H_
#define GPIOINT_H_

#include "LPC17xx.h"
#include "queue.h"
#include "portmacro.h"

/**
 * Maximum amount of subscribers allowed
 */
#define GPIOINT_MAX_SUBSCRIBERS 10

#define GPIOINT_NVIC_PRIORITY 5

/**
 * Enables the GPIO interrupts
 */
void GPIOINT_enable();
#define GPIOINT_disable() NVIC_DisableIRQ(EINT3_IRQn)

typedef struct {
	volatile uint32_t *statusRegister;
	volatile uint32_t *clearRegister;
	uint32_t statusBitMask;
	xQueueHandle queueHandle;
} GPIOINT_desc;

typedef enum {
	rising,
	falling
} GPIOINT_direction;

/**
 * Creates an interrupt as provided by the parameters, and subscribes to the
 * ISR. A queue handle is initialized into the GPIOINT_desc struct, that can be
 * used to retrieve when an interrupt has happened
 *
 * @param desc A GPIOINT_desc that'll be initialized by the function
 * @param port The port number of the pin (0 or 2)
 * @param pin  The pin number in the port
 * @param direction The direction of the interrupt to subscribe to
 * @param queueSize The size of the queue that'll hold the interrupt events
 *
 * @return 0 on failure, 1 on success
 */
uint8_t GPIOINT_subscribe(GPIOINT_desc *desc, uint8_t port, uint8_t pin, GPIOINT_direction direction, unsigned portBASE_TYPE queueSize);

/**
 * The ISR used by GPIO
 */
void EINT3_IRQHandler(void);

#endif /* GPIOINT_H_ */
