/**
 * Pulse width module
 */

#ifndef PWM_H_
#define PWM_H_

#include <stdint.h>

/**
 * Enables the PWM functionality in the microcontroller
 */
void PWM_initialize();

/**
 * Sets the pin operating mode
 *
 * @param channel The channel number, which is between 0 and 6
 *
 * @return 0 on failure and 1 on sucess
 */
uint8_t PWM_channelSetup(uint8_t channel);

/**
 * Sets up a PWM channel with the given percentage of the duty on HIGH.
 * It can be called directly. The PWM will be initialized and the channel set up.
 *
 * @param channel The channel number, which is between 0 and 6
 * @param dutyPercent The percentage, between 0 and 100, that the pulse is HIGH
 *
 * @return 0 on failure and 1 on sucess
 */
uint8_t PWM_channelDuty(uint8_t channel, uint8_t dutyPercent);

void PWM_updateDuty();

#endif /* PWM_H_ */
