#ifndef TIMER_H_
#define TIMER_H_

#include <stdint.h>

/**
 * Contains the current elapsed time in microseconds
 */
extern volatile uint32_t *Timer_usTime;

/**
 * Initializes the timer so that it's ready for usage
 */
void Timer_Setup();

/**
 * Introduces a software delay without using a context switch.
 * It still allows preemption.
 *
 * @param us The delay in microseconds
 */
void Timer_usDelay(uint32_t us);

/**
 * Introduces a software delay without using a context switch.
 * It still allows preemption.
 *
 * @param ms The delay in milliseconds
 */
void Timer_msDelay(uint32_t ms);

/**
 * Function that checks how much time has elapsed since the given timestamp.
 * It handles counter overflow correctly if it happened once at most.
 *
 * @param previousTs The starting timestamp in microseconds
 *
 * @return The elapsed time in microseconds
 */
uint32_t Timer_usElapsed(uint32_t previousTs);


#endif /* TIMER_H_ */
