#ifndef UART_H_
#define UART_H_

#include <stdint.h>
#include "FreeRTOS.h"
#include "queue.h"

#define UART_NVIC_PRIORITY 10

typedef enum { UART_WORD_5_BIT, UART_WORD_6_BIT, UART_WORD_7_BIT, UART_WORD_8_BIT } UART_WordLength;

/**
 * Initializes a UART channel so that it can be used
 *
 * @param uartNum The UART channel number, from 0 to 3
 * @param wordLength The word length used by the devices
 * @param bauds The rate used by the devices
 * @param queue A queue handle where received characters will be put
 *
 * @return 0 on failure, 1 on success
 */
uint8_t UART_Setup(uint8_t uartNum, UART_WordLength wordLength, uint32_t bauds, xQueueHandle queue);

/**
 * Writes to a UART channel
 *
 * @param uartNum The UART channel number, from 0 to 3
 * @param *string A pointer to the string to be sent
 * @param length The length of the string to be sent
 *
 * @return 0 on failure, 1 on success
 */
uint8_t UART_Write(uint8_t uartNum, uint8_t *string, uint8_t length);

/**
 * NVIC interrupt handler for this uart channel
 */
void UART0_IRQHandler();

/**
 * NVIC interrupt handler for this uart channel
 */
void UART1_IRQHandler();

/**
 * NVIC interrupt handler for this uart channel
 */
void UART2_IRQHandler();

/**
 * NVIC interrupt handler for this uart channel
 */
void UART3_IRQHandler();


#endif /* UART_H_ */
