#include "LPC17xx.h"
#include "system_LPC17xx.h"
#include "bit.h"
#include "PWM.h"

/**
 * A flag to check if we already initialized the PWM functionality
 */
static uint8_t PWM_initialized = 0;

/**
 * A bitmask with the channels that have already been initialized
 */
static uint8_t PWM_channelsSet = 0;

void PWM_initialize()
{
	Bit_on(LPC_SC->PCONP, 1 << 6); //Enable PWM power/clock
	Bit_off(LPC_SC->PCLKSEL0, 3 << 12); //Set clock divisor to 4

	LPC_PWM1->TCR = 0; //Disable PWM
	LPC_PWM1->PCR = 0; //Disable all channels
	LPC_PWM1->PR = 24 * 10; //Prescale register to 10 microsecond
	LPC_PWM1->MCR = 1 << 1; //Match control register to reset MR0 on match
	LPC_PWM1->MR0 = 100; //Set MR0 match value
	LPC_PWM1->LER = 1; //Propagate new match registers
	LPC_PWM1->TCR = 9; //Enable timer control and set it to PWM mode

	PWM_initialized = 1;
}

/**
 * Sets the pin operating mode
 */
uint8_t PWM_channelSetup(uint8_t channel)
{
	if (channel < 1 || channel > 6) {
		return 0;
	}

	if (!PWM_initialized) {
		PWM_initialize();
	}

	uint8_t bitmask = 1 << (channel - 1) * 2;

	Bit_on(LPC_PINCON->PINSEL4, bitmask);
	Bit_off(LPC_PINCON->PINSEL4, bitmask << 1);

	Bit_on(PWM_channelsSet, 1 << channel);
	Bit_on(LPC_PWM1->PCR, 1 << (8 + channel)); //Enable PWM outputs and set to single edge

	return 1;
}

uint8_t PWM_channelDuty(uint8_t channel, uint8_t dutyPercent)
{
	if (channel <= 0 || channel >= 6 || dutyPercent > 100) {
		return 0;
	}

	if (!Bit_isSet(PWM_channelsSet, 1 << channel)) {
		PWM_channelSetup(channel);
	}

	if (channel == 1) {
		LPC_PWM1->MR1 = dutyPercent;
	} else if (channel == 2) {
		LPC_PWM1->MR2 = dutyPercent;
	} else if (channel == 3) {
		LPC_PWM1->MR3 = dutyPercent;
	} else if (channel == 4) {
		LPC_PWM1->MR4 = dutyPercent;
	} else if (channel == 5) {
		LPC_PWM1->MR5 = dutyPercent;
	} else if (channel == 6) {
		LPC_PWM1->MR1 = dutyPercent;
	}

	return 1;
}

void PWM_updateDuty()
{
	LPC_PWM1->LER = 0x7E; //Propagate new match registers
}
