/**
 * Debugging module. Provides stack size monitoring and ability to switch
 * expressions on and off.
 */

#ifndef DEBUG_H_
#define DEBUG_H_

#include <stdint.h>
#include "FreeRTOS.h"
#include "task.h"

#define DEBUG_EXPRESSION_ENABLE 1
#define DEBUG_STACK 1

#define DEBUG_NUM_TASKS 10
#define DEBUG_STACK_ITERATION_DELAY 5000

#if DEBUG_STACK
	/**
	 * Enable the stack size monitoring
	 */
	void Debug_StackMonitor();
	/**
	 * Retrieves the pointer to task handler in the given index
	 * @precondition 0 >= index < DEBUG_NUM_TASKS
	 *
	 * @param index
	 */
	xTaskHandle* Debug_getTaskHandler(uint8_t index);
	#define DEBUG_TASK_HANDLE(index) Debug_getTaskHandler(index)
	#define DEBUG_STACK_TASK() xTaskCreate(Debug_StackMonitor, "Stack mon", 240, NULL, 0, NULL)
#else
	#define DEBUG_TASK_HANDLE(var) NULL
	#define DEBUG_STACK_TASK() while(0)
#endif

#define DEBUG_EXPRESSION(expression) if (DEBUG_EXPRESSION_ENABLE) { expression; }

#endif /* DEBUG_H_ */
