#ifndef LOG_H_
#define LOG_H_
#include <stdint.h>
#include <stdarg.h>

typedef enum {LOG_DEBUG, LOG_INFO, LOG_WARNING, LOG_ERROR} Log_Level;

#define LOG_BUFFER_SIZE 255

/**
 * Initializes the loggin module
 *
 * @param uartNum The UART channel number that'll be used for the output
 */
void Log_Setup(uint8_t uartNum);

/**
 * The task that'll write to the UART if there's something in the LOG buffer.
 * This task should have a low priority so that the logging does not interfere
 * with normal operation.
 */
void Log_Task();

/**
 * Write a message to the log buffer
 *
 * @param format A printf compatible format string
 * @param ... Additional arguments as per format requirement
 */
void Log_Write(uint8_t *format, ...);

/**
 * Sets the minimum logging level required for the messages to be sent
 *
 * @param level The new log level
 *
 * @return The previous log level
 */
Log_Level Log_SetLevel(Log_Level level);

/**
 * Checks whether the logging is enabled for the given log level
 *
 * @param level The log level to check against
 *
 * @return 1 if enabled, 0 if disabled
 */
uint8_t Log_Enabled(Log_Level level);

/**
 * Disables the logging functionality
 */
void Log_Disable();

/**
 * Enables the logging functionality
 */
void Log_Enable();

#define LOG_ENABLED 0
#define LOG_DEFAULT_LEVEL LOG_DEBUG

#if LOG_ENABLED == 1
	#define LOG_IF_ENABLED(LEVEL) (Log_Enabled(LEVEL))
#else
	#define LOG_IF_ENABLED(LEVEL) (0)
#endif

#endif /* LOG_H_ */
