#include "FreeRTOSConfig.h"
#include "FreeRTOS.h"
#include "task.h"
#include "debug.h"
#include "sonar.h"
#include <WatchDog.h>
#include "main.h"
#include "LPC17xx.h"
#include <bit.h>
#include "proximity.h"
#include "PWM.h"
#include "ecuFeedback.h"
#include "wiflyTerm.h"
#include "log.h"

static xTaskHandle mainSetupTaskHandle;

int main(void) {
	xTaskCreate(mainSetupTask, "Main setup", 300, NULL, 5, mainSetupTaskHandle);
	vTaskStartScheduler();

	for(;;) {

	}

    return 0;
}

void mainSetupTask()
{
	Sonar_setup(Proximity_setup());
	WiflyTerm_Setup();
	EcuFeedback_Setup();

	xTaskCreate(Sonar_triggerTask, "Sonar trigger", configMINIMAL_STACK_SIZE, NULL, 1, DEBUG_TASK_HANDLE(0));
	xTaskCreate(Sonar_distanceTaskDevice1, "Sonar dist1", 170, NULL, 2, DEBUG_TASK_HANDLE(1));
	xTaskCreate(Sonar_distanceTaskDevice2, "Sonar dist2", 170, NULL, 2, DEBUG_TASK_HANDLE(2));
	xTaskCreate(Proximity_dispatchTask, "Proximity", 200, NULL, 3, DEBUG_TASK_HANDLE(3));
	xTaskCreate(EcuFeedback_Task, "Ecu feedback", 200, NULL, 0, DEBUG_TASK_HANDLE(4));
#if LOG_ENABLED
	xTaskCreate(Log_Task, "Log task", 200, NULL, 0, DEBUG_TASK_HANDLE(6));
	xTaskCreate(WiflyTerm_Task, "Wifly term", 200, NULL, 0, DEBUG_TASK_HANDLE(7));
#endif
	if (WATCHDOG_ENABLED) {
		xTaskCreate(feedWatchdogTask, "Watchdog feed", configMINIMAL_STACK_SIZE, NULL, 0, DEBUG_TASK_HANDLE(5));
		WatchDog_enable(WATCHDOG_FEED_TIMEOUT);
	}
	DEBUG_STACK_TASK();
	vTaskDelete(mainSetupTaskHandle);
}

void feedWatchdogTask()
{
	for(;;) {
		WatchDog_feed();
		if (Bit_isSet(LPC_WDT->WDMOD, 1 << 2)) {
			Bit_off(LPC_WDT->WDMOD, 1 << 2);
			DEBUG_EXPRESSION(printf("Watchdog timed out\n"));
		} else {
			DEBUG_EXPRESSION(printf("Watchdog alive\n"));
		}
		vTaskDelay(WATCHDOG_FEED_TIMEOUT / 5);
	}
}
