/**
 * Proximity alerts module. Processes sonar values sent to it and asseses
 * risk and then provides feedback.
 */

#ifndef PROXIMITY_H_
#define PROXIMITY_H_
#include "queue.h"
#include "sonar.h"

//Ability to queue 1 measurement from each sonar(2) plus extra wiggle room
#define PROXIMITY_MEASUREMENTS_QUEUE_SIZE 3

#define PROXIMITY_NUM_SOURCES 2
#define PROXIMITY_LEFT_SONAR_SOURCE 0
#define PROXIMITY_RIGHT_SONAR_SOURCE 1

#define PROXIMITY_MS_PER_SAMPLE (portTICK_RATE_MS * SONAR_TRIGGER_DELAY)
#define PROXIMITY_MAX_DISTANCE SONAR_MAX_SENSING_DISTANCE
#define PROXIMITY_MAX_APPROACHING_SPEED PROXIMITY_MAX_DISTANCE

#define PROXIMITY_HIGH_SCORE_FROM 66
#define PROXIMITY_MEDIUM_SCORE_FROM 33
#define PROXIMITY_LOW_SCORE_FROM 0

#define PROXIMITY_UPDATE_SEMAPHORE_MAX_WAIT 50

/**
 * Initializes the proximity module
 *
 * @return A queue handler where it'll ready measurements from
 */
xQueueHandle Proximity_setup();

/**
 * A task that reads sonar proximity values, calculate risks, and outputs
 * alerts
 */
void Proximity_dispatchTask();



#endif /* PROXIMITY_H_ */
