/**
 * Takes sonar measurements and sends them into a queue
 */

#ifndef SONAR_H_
#define SONAR_H_

#include "queue.h"
#include <stdint.h>

#define SONAR_TRIGGER_PIN1 7
#define SONAR_TRIGGER_PIN2 9
#define SONAR_TRIGGER_DELAY 60
#define SONAR_MEASUREMENT_MAX_DELAY 50
#define SONAR_MEASUREMENTS_QUEUE_WAIT SONAR_MEASUREMENT_MAX_DELAY * 8 / 10

#define SONAR_MAX_SENSING_DISTANCE 590

#define SONAR_RX_PORT 0
#define SONAR_RX_PIN1 6
#define SONAR_RX_PIN2 8
#define SONAR_QUEUE_SIZE 2
#define SONAR_FIO_PIN_MASK ((1 << SONAR_TRIGGER_PIN1) | (1 << SONAR_TRIGGER_PIN2))

typedef struct {
	uint8_t source;
	uint16_t distance;
} Sonar_measurement;

/**
 * Initializes the sonar functionality.
 * Configures the pins and sets up the interrupts
 *
 * @param queue Queue where Sonar_measurement will be pushed
 */
void Sonar_setup(xQueueHandle queue);
/**
 * A task for sending a periodic signal to the sonar HW module to take
 * a measurement
 *
 * @precondition Sonar_setup has been called
 */
void Sonar_triggerTask();
/**
 * A task for processing the measurements from the sonar 1
 * @precondition Sonar_setup has been called
 */
void Sonar_distanceTaskDevice1();
/**
 * A task for processing the measurements from the sonar 2
 * @precondition Sonar_setup has been called
 */
void Sonar_distanceTaskDevice2();

#endif /* SONAR_H_ */
