#include "FreeRTOS.h"
#include "queue.h"
#include "UART.h"
#include "log.h"
#include "wiflyTerm.h"
#include "debug.h"

static xQueueHandle receiveQueue;

void WiflyTerm_Setup()
{
	receiveQueue = xQueueCreate(WIFLYTERM_UART_RECEIVE_BUFFER, sizeof(uint8_t));
	UART_Setup(WIFLYTERM_UART_NUM, UART_WORD_8_BIT, WIFLYTERM_UART_BAUDS, receiveQueue);
	Log_Setup(WIFLYTERM_UART_NUM);
}

void WiflyTerm_Task()
{
	uint8_t character, state = 0;
	uint8_t openString[] = "*OPEN*";
	uint8_t closeString[] = "*CLOS*";

	UART_Write(WIFLYTERM_UART_NUM, "Start", 5); //Helps make the wifly aware and stop sending rubbish

	for(;;) {
		if (xQueueReceive(receiveQueue, &character, portMAX_DELAY)) {
			switch(state) {
				case WIFLY_GRAPH_FIRST:
					if (character == '*') {
						state = WIFLY_GRAPH_COMMAND_SELECT;
					}
					break;
				case WIFLY_GRAPH_COMMAND_SELECT:
					if (character == openString[1]) {
						state = WIFLY_GRAPH_OPEN_0;
					} else if(character == closeString[1]) {
						state = WIFLY_GRAPH_CLOSE_0;
					} else {
						state = WIFLY_GRAPH_FIRST;
					}
					break;
				case WIFLY_GRAPH_OPEN_0:
				case WIFLY_GRAPH_OPEN_1:
				case WIFLY_GRAPH_OPEN_2:
					if (character == openString[(state / 2) + 1]) {
						state += 2;
					} else {
						state = WIFLY_GRAPH_FIRST;
					}
					break;
				case WIFLY_GRAPH_OPEN_3:
					if (character == openString[(state / 2) + 1]) {
						Log_Enable();
						DEBUG_EXPRESSION(printf("Enabling remote logging\n"));
					}
					state = WIFLY_GRAPH_FIRST;
					break;
				case WIFLY_GRAPH_CLOSE_0:
				case WIFLY_GRAPH_CLOSE_1:
				case WIFLY_GRAPH_CLOSE_2:
					if (character == closeString[(state / 2) + 1]) {
						state += 2;
					} else {
						state = WIFLY_GRAPH_FIRST;
					}
					break;
				case WIFLY_GRAPH_CLOSE_3:
					if (character == closeString[(state / 2) + 1]) {
						Log_Disable();
						DEBUG_EXPRESSION(printf("Disabling remote logging\n"));
					}
					state = WIFLY_GRAPH_FIRST;
					break;
			}
		}
	}
}
